@@ -165,7 +165,7 @@ class MultipleFactor(object):
             w = copy.deepcopy(this_data)
             #kd_logger.info("calc returns correlation begin_date:{0}, end_date:{1}".format(
             #    begin_date, end_date))
-            corr_dt = self._returns_corr(returns)
+            corr_dt = self._returns_corr(returns).fillna(0)
 
             ###重置w, 波动率顺序
             w = w.set_index('code').reindex(corr_dt.index).reset_index()
@@ -181,6 +181,8 @@ class MultipleFactor(object):
                 print(n.shape[0], n.shape[0])
             else:
                 m = np.dot(n,s)
+                if m ==0:
+                    continue
                 #op = 1 / (s/v).sum() * m
                 op = math.sqrt(m)
                 weighted_data = copy.deepcopy(this_data)
@@ -232,4 +234,4 @@ class MultipleFactor(object):
         weighted_returns = (np.exp(forward_returns['nxt1_ret']) - 1).multiply(weights, axis=0)
         factor_ret_se = weighted_returns.groupby(level='trade_date').sum()
         factor_ret_se = np.log(1 + factor_ret_se)
-        return factor_ret_se,leverags,weights
+        return factor_ret_se,leverags,weights
\ No newline at end of file
